@@ -1,9 +1,9 @@
 from .loader import load_model
-#from .converter import ConvertToOnnx, ConvertToTF
-import quantization
+from . import converter
+from . import quantization
 
 __all__ = [
         'load_model',
+        'quantization',
         'converter',
-        'quantization'
         ]
